@@ -39,7 +39,7 @@
  * These restrictions only apply when you actually redistribute Nmap.  For *
  * example, nothing stops you from writing and selling a proprietary       *
  * front-end to Nmap.  Just distribute it by itself, and point people to   *
- * http://insecure.org/nmap/ to download Nmap.                             *
+ * http://nmap.org to download Nmap.                                       *
  *                                                                         *
  * We don't consider these to be added restrictions on top of the GPL, but *
  * just a clarification of how we interpret "derived works" as it applies  *
@@ -78,7 +78,7 @@
  * Source code also allows you to port Nmap to new platforms, fix bugs,    *
  * and add new features.  You are highly encouraged to send your changes   *
  * to fyodor@insecure.org for possible incorporation into the main         *
- * distribution.  By sending these changes to Fyodor or one the            *
+ * distribution.  By sending these changes to Fyodor or one of the         *
  * Insecure.Org development mailing lists, it is assumed that you are      *
  * offering Fyodor and Insecure.Com LLC the unlimited, non-exclusive right *
  * to reuse, modify, and relicense the code.  Nmap will always be          *
@@ -98,7 +98,7 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: MACLookup.cc 6633 2007-12-22 06:32:03Z fyodor $ */
+/* $Id: MACLookup.cc 7023 2008-03-31 23:05:53Z david $ */
 
 
 /* Character pool memory allocation */
@@ -150,7 +150,7 @@ static void mac_prefix_init() {
 
   /* Now it is time to read in all of the entries ... */
   if (nmap_fetchfile(filename, sizeof(filename), "nmap-mac-prefixes") != 1){
-    error("Cannot find nmap-mac-prefixes: Ethernet vendor corolation will not be performed");
+    error("Cannot find nmap-mac-prefixes: Ethernet vendor correlation will not be performed");
     return;
   }
 
