@@ -38,7 +38,7 @@
  * These restrictions only apply when you actually redistribute Nmap.  For *
  * example, nothing stops you from writing and selling a proprietary       *
  * front-end to Nmap.  Just distribute it by itself, and point people to   *
- * http://insecure.org/nmap/ to download Nmap.                             *
+ * http://nmap.org to download Nmap.                                       *
  *                                                                         *
  * We don't consider these to be added restrictions on top of the GPL, but *
  * just a clarification of how we interpret "derived works" as it applies  *
@@ -77,7 +77,7 @@
  * Source code also allows you to port Nmap to new platforms, fix bugs,    *
  * and add new features.  You are highly encouraged to send your changes   *
  * to fyodor@insecure.org for possible incorporation into the main         *
- * distribution.  By sending these changes to Fyodor or one the            *
+ * distribution.  By sending these changes to Fyodor or one of the         *
  * Insecure.Org development mailing lists, it is assumed that you are      *
  * offering Fyodor and Insecure.Com LLC the unlimited, non-exclusive right *
  * to reuse, modify, and relicense the code.  Nmap will always be          *
@@ -97,7 +97,7 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: global_structures.h 6633 2007-12-22 06:32:03Z fyodor $ */
+/* $Id: global_structures.h 7148 2008-04-11 18:57:32Z david $ */
 
 
 #ifndef GLOBAL_STRUCTURES_H
@@ -135,16 +135,6 @@ struct udpprobeinfo {
   struct in_addr target;
 };
 
-struct connectsockinfo {
-  fd_set fds_read;
-  fd_set fds_write;
-  fd_set fds_except;
-  struct portinfo *socklookup[2048]; /* index socket descriptor -> scan[] 
-					index.  No OS better give us
-					an SD > 2047!@#$ */
-  int maxsd;
-};
-
 /* The runtime statistics used to decide how fast to proced and how
    many ports we can try at once */
 struct scanstats {
@@ -212,8 +202,6 @@ struct timeout_info {
 
 struct seq_info {
   int responses;
-  int seqclass; /* SEQ_* defines in nmap.h.  This should be removed when
-		 we remove osscan gen1 cruft. */
   int ts_seqclass; /* TS_SEQ_* defines in nmap.h */
   time_t uptime; /* time of latest system boot (or 0 if unknown ) */
   int ipid_seqclass; /* IPID_SEQ_* defines in nmap.h */
