@@ -38,7 +38,7 @@
  * These restrictions only apply when you actually redistribute Nmap.  For *
  * example, nothing stops you from writing and selling a proprietary       *
  * front-end to Nmap.  Just distribute it by itself, and point people to   *
- * http://insecure.org/nmap/ to download Nmap.                             *
+ * http://nmap.org to download Nmap.                                       *
  *                                                                         *
  * We don't consider these to be added restrictions on top of the GPL, but *
  * just a clarification of how we interpret "derived works" as it applies  *
@@ -77,7 +77,7 @@
  * Source code also allows you to port Nmap to new platforms, fix bugs,    *
  * and add new features.  You are highly encouraged to send your changes   *
  * to fyodor@insecure.org for possible incorporation into the main         *
- * distribution.  By sending these changes to Fyodor or one the            *
+ * distribution.  By sending these changes to Fyodor or one of the         *
  * Insecure.Org development mailing lists, it is assumed that you are      *
  * offering Fyodor and Insecure.Com LLC the unlimited, non-exclusive right *
  * to reuse, modify, and relicense the code.  Nmap will always be          *
@@ -97,7 +97,9 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: main.cc 6633 2007-12-22 06:32:03Z fyodor $ */
+/* $Id: main.cc 7182 2008-04-24 03:23:01Z fyodor $ */
+
+#include <signal.h>
 
 #include "nmap.h"
 #include "NmapOps.h"
@@ -155,7 +157,6 @@ int main(int argc, char *argv[]) {
   char *endptr;
   int interactivemode = 0;
   int fd;
-  struct timeval tv;
   int arglen = 0;
 
 #ifdef __amigaos__
@@ -178,10 +179,6 @@ int main(int argc, char *argv[]) {
   mtrace();
 #endif
 
-  /* You never know when "random" numbers will come in handy ... */
-  gettimeofday(&tv, NULL);
-  srand((tv.tv_sec ^ tv.tv_usec) ^ getpid());
-
   /* Trap these sigs for cleanup */
 #if HAVE_SIGNAL
   signal(SIGINT, sigdie);
@@ -226,7 +223,7 @@ int main(int argc, char *argv[]) {
     }
     return nmap_main(argc, argv);
   }
-  /*  printf("\nStarting nmap V. %s by fyodor@insecure.org ( www.insecure.org/nmap/ )\n", VERSION);*/
+
   printf("\nStarting %s V. %s ( %s )\n", NMAP_NAME, NMAP_VERSION, NMAP_URL);
 
   printf("Welcome to Interactive Mode -- press h <enter> for help\n");
