@@ -39,7 +39,7 @@
  * These restrictions only apply when you actually redistribute Nmap.  For *
  * example, nothing stops you from writing and selling a proprietary       *
  * front-end to Nmap.  Just distribute it by itself, and point people to   *
- * http://insecure.org/nmap/ to download Nmap.                             *
+ * http://nmap.org to download Nmap.                                       *
  *                                                                         *
  * We don't consider these to be added restrictions on top of the GPL, but *
  * just a clarification of how we interpret "derived works" as it applies  *
@@ -78,7 +78,7 @@
  * Source code also allows you to port Nmap to new platforms, fix bugs,    *
  * and add new features.  You are highly encouraged to send your changes   *
  * to fyodor@insecure.org for possible incorporation into the main         *
- * distribution.  By sending these changes to Fyodor or one the            *
+ * distribution.  By sending these changes to Fyodor or one of the         *
  * Insecure.Org development mailing lists, it is assumed that you are      *
  * offering Fyodor and Insecure.Com LLC the unlimited, non-exclusive right *
  * to reuse, modify, and relicense the code.  Nmap will always be          *
@@ -98,11 +98,12 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: nbase_rnd.c 6636 2007-12-22 06:32:28Z fyodor $ */
+/* $Id: nbase_rnd.c 7259 2008-04-30 20:43:09Z bmenrigh $ */
 
 #include "nbase.h"
 #include <string.h>
 #include <stdio.h>
+#include <stdlib.h>
 #if HAVE_SYS_TIME_H
 #include <sys/time.h>
 #endif
@@ -117,6 +118,7 @@ int get_random_bytes(void *buf, int numbytes) {
   FILE *fp = NULL;
   unsigned int i;
   short *iptr;
+  short step;
   
   if (numbytes < 0 || numbytes > 0xFFFF) return -1;
   
@@ -142,12 +144,14 @@ int get_random_bytes(void *buf, int numbytes) {
 	gettimeofday(&tv, NULL);
 	srand((tv.tv_sec ^ tv.tv_usec) ^ getpid());
       }
-      
-      for(i=0; i < sizeof(bytebuf) / sizeof(short); i++) {
-	iptr = (short *) ((char *)bytebuf + i * sizeof(short));
+      if (RAND_MAX >= 0xFFFF) {
+        step = sizeof(short);
+      } else step = 1;
+      for(i=0; i < sizeof(bytebuf) / step; i++) {
+	iptr = (short *) ((char *)bytebuf + i * step);
 	*iptr = rand();
       }
-      bytesleft = (sizeof(bytebuf) / sizeof(short)) * sizeof(short);
+      bytesleft = (sizeof(bytebuf) / step) * step;
       /*    ^^^^^^^^^^^^^^^not as meaningless as it looks  */
     } else fclose(fp);
   }
