@@ -39,7 +39,7 @@
  * These restrictions only apply when you actually redistribute Nmap.  For *
  * example, nothing stops you from writing and selling a proprietary       *
  * front-end to Nmap.  Just distribute it by itself, and point people to   *
- * http://insecure.org/nmap/ to download Nmap.                             *
+ * http://nmap.org to download Nmap.                                       *
  *                                                                         *
  * We don't consider these to be added restrictions on top of the GPL, but *
  * just a clarification of how we interpret "derived works" as it applies  *
@@ -78,7 +78,7 @@
  * Source code also allows you to port Nmap to new platforms, fix bugs,    *
  * and add new features.  You are highly encouraged to send your changes   *
  * to fyodor@insecure.org for possible incorporation into the main         *
- * distribution.  By sending these changes to Fyodor or one the            *
+ * distribution.  By sending these changes to Fyodor or one of the         *
  * Insecure.Org development mailing lists, it is assumed that you are      *
  * offering Fyodor and Insecure.Com LLC the unlimited, non-exclusive right *
  * to reuse, modify, and relicense the code.  Nmap will always be          *
@@ -98,7 +98,7 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: nmap.h 6676 2008-01-12 22:39:34Z fyodor $ */
+/* $Id: nmap.h 7301 2008-05-03 08:22:18Z fyodor $ */
 
 #ifndef NMAP_H
 #define NMAP_H
@@ -110,7 +110,7 @@
 #endif
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include "nmap_config.h"
 #else
 #ifdef WIN32
 #include "nmap_winconfig.h"
@@ -253,8 +253,8 @@ void *realloc();
 #ifndef NMAP_VERSION
 /* Edit this definition only within the quotes, because it is read from this
    file by the makefiles. */
-#define NMAP_VERSION "4.53"
-#define NMAP_NUM_VERSION "4.53.0.0"
+#define NMAP_VERSION "4.62"
+#define NMAP_NUM_VERSION "4.62.0.0"
 #endif
 
 /* User configurable #defines: */
@@ -358,15 +358,6 @@ void *realloc();
    wrapped. */
 #define FP_RESULT_WRAP_LINE_LEN 74
 
-/* TCP/IP ISN sequence prediction classes */
-#define SEQ_UNKNOWN 0
-#define SEQ_64K 1
-#define SEQ_TD 2
-#define SEQ_RI 4
-#define SEQ_TR 8
-#define SEQ_i800 16
-#define SEQ_CONSTANT 32
-
 /* TCP Timestamp Sequence */
 #define TS_SEQ_UNKNOWN 0
 #define TS_SEQ_ZERO 1 /* At least one of the timestamps we received back was 0 */
@@ -410,8 +401,8 @@ void printinteractiveusage();
 int ftp_anon_connect(struct ftpinfo *ftp);
 
 /* port manipulators */
-struct scan_lists *getpts(char *expr); /* someone stole the name getports()! */
-void getpts_simple(char *origexpr, int range_type,
+struct scan_lists *getpts(const char *expr); /* someone stole the name getports()! */
+void getpts_simple(const char *origexpr, int range_type,
                    unsigned short **list, int *count);
 void free_scan_lists(struct scan_lists *ports);
 
@@ -425,21 +416,21 @@ void nmap_free_mem();
 
 /* general helper functions */
 int parse_targets(struct targets *targets, char *h);
-char *statenum2str(int state);
-char *scantype2str(stype scantype);
+const char *statenum2str(int state);
+const char *scantype2str(stype scantype);
 void sigdie(int signo);
 void reaper(int signo);
 char *seqreport(struct seq_info *seq);
 char *seqreport1(struct seq_info *seq);
-char *seqclass2ascii(int clas);
-char *ipidclass2ascii(int seqclass);
-char *tsseqclass2ascii(int seqclass);
+const char *seqclass2ascii(int clas);
+const char *ipidclass2ascii(int seqclass);
+const char *tsseqclass2ascii(int seqclass);
 
 /* Convert a TCP sequence prediction difficulty index like 1264386
    into a difficulty string like "Worthy Challenge */
 const char *seqidx2difficultystr(unsigned long idx);
 const char *seqidx2difficultystr1(unsigned long idx);
-int nmap_fetchfile(char *filename_returned, int bufferlen, char *file);
+int nmap_fetchfile(char *filename_returned, int bufferlen, const char *file);
 int nmap_fileexistsandisreadable(char* pathname);
 int gather_logfile_resumption_state(char *fname, int *myargc, char ***myargv);
 
