@@ -37,7 +37,7 @@
  * These restrictions only apply when you actually redistribute Nmap.  For *
  * example, nothing stops you from writing and selling a proprietary       *
  * front-end to Nmap.  Just distribute it by itself, and point people to   *
- * http://insecure.org/nmap/ to download Nmap.                             *
+ * http://nmap.org to download Nmap.                                       *
  *                                                                         *
  * We don't consider these to be added restrictions on top of the GPL, but *
  * just a clarification of how we interpret "derived works" as it applies  *
@@ -76,7 +76,7 @@
  * Source code also allows you to port Nmap to new platforms, fix bugs,    *
  * and add new features.  You are highly encouraged to send your changes   *
  * to fyodor@insecure.org for possible incorporation into the main         *
- * distribution.  By sending these changes to Fyodor or one the            *
+ * distribution.  By sending these changes to Fyodor or one of the         *
  * Insecure.Org development mailing lists, it is assumed that you are      *
  * offering Fyodor and Insecure.Com LLC the unlimited, non-exclusive right *
  * to reuse, modify, and relicense the code.  Nmap will always be          *
@@ -97,7 +97,7 @@
  ***************************************************************************/
 
 #ifndef WIN32
-#include "config.h"
+#include "nmap_config.h"
 #endif
 
 #include <sys/types.h>
@@ -207,6 +207,9 @@ void tty_init()
 {
 	struct termios ti;
 
+	if(o.noninteractive)
+		return;
+
 	if (tty_fd)
 		return;
 
@@ -273,7 +276,7 @@ bool keyWasPressed()
 		"d/D             Increase/decrease debugging\n"
 		"p/P             Enable/disable packet tracing\n"
 		"anything else   Print status\n"
-                "More help: http://www.insecure.org/nmap/man/man-runtime-interaction.html\n");
+                "More help: http://nmap.org/man/man-runtime-interaction.html\n");
     } else {
        printStatusMessage();
        return true;
