@@ -145,6 +145,7 @@ int script_scan(std::vector<Target*> &targets) {
 	int status;
 	std::vector<Target*>::iterator target_iter;
 	std::list<std::list<struct thread_record> >::iterator runlevel_iter;
+	std::list<struct thread_record>::iterator thr_iter;
 	std::list<struct thread_record> torun_threads;
 	lua_State* l;
 
@@ -156,12 +157,13 @@ int script_scan(std::vector<Target*> &targets) {
 
 	SCRIPT_ENGINE_DEBUGGING(
 		unsigned int tlen = targets.size();
+		char targetstr[128];
 		if(tlen > 1)
 			log_write(LOG_STDOUT, "%s: Script scanning %d hosts.\n", 
 				SCRIPT_ENGINE, tlen);
 		else
 			log_write(LOG_STDOUT, "%s: Script scanning %s.\n", 
-				SCRIPT_ENGINE, (*targets.begin())->HostName());
+				SCRIPT_ENGINE, (*targets.begin())->NameIP(targetstr, sizeof(targetstr)));
 	)
 
 	l = lua_open();
@@ -211,6 +213,15 @@ int script_scan(std::vector<Target*> &targets) {
 					SCRIPT_ENGINE,
 					running_scripts.front().runlevel);)
 
+		/* Start the time-out clocks for targets with scripts in this
+		 * runlevel.  The clock is stopped in process_finalize().
+		 */
+		for (thr_iter = running_scripts.begin();
+		     thr_iter != running_scripts.end();
+		     thr_iter++)
+			if (!thr_iter->rr->host->timeOutClockRunning())
+				thr_iter->rr->host->startTimeOutClock(NULL);
+
 		status = process_mainloop(l);
 		if(status != SCRIPT_ENGINE_SUCCESS){
 			goto finishup;
@@ -286,55 +297,54 @@ int process_mainloop(lua_State* l) {
 			}
 
 
-		if(running_scripts.begin() == running_scripts.end())
-			continue;
-
-		current = *(running_scripts.begin());
-
-		if (current.rr->host->timedOut(&now))
-			state = LUA_ERRRUN;
-		else
-			state = lua_resume(current.thread, current.resume_arguments);
-
-		if(state == LUA_YIELD) {
-			// this script has performed a network io operation
-			// we put it in the waiting
-			// when the network io operation has completed,
-			// a callback from the nsock library will put the
-			// script back into the running state
-			
-			waiting_scripts.push_back(current);
-			running_scripts.pop_front();
-		} else if( state == 0) {
-			// this script has finished
-			// we first check if it produced output
-			// then we release the thread and remove it from the
-			// running_scripts list
-
-			if(lua_isstring (current.thread, -1)) {
-				SCRIPT_ENGINE_TRY(process_getScriptId(current.thread, &ssr));
-				ssr.output = nse_printable
-					(lua_tostring(current.thread, -1), lua_objlen(current.thread, -1));
-				if(current.rr->type == 0) {
-					current.rr->host->scriptResults.push_back(ssr);
-				} else if(current.rr->type == 1) {
-					current.rr->port->scriptResults.push_back(ssr);
-					current.rr->host->ports.numscriptresults++;
+		while(running_scripts.begin() != running_scripts.end()){
+			current = *(running_scripts.begin());
+	
+			if (current.rr->host->timedOut(&now))
+				state = LUA_ERRRUN;
+			else
+				state = lua_resume(current.thread, current.resume_arguments);
+	
+			if(state == LUA_YIELD) {
+				// this script has performed a network io operation
+				// we put it in the waiting
+				// when the network io operation has completed,
+				// a callback from the nsock library will put the
+				// script back into the running state
+				
+				waiting_scripts.push_back(current);
+				running_scripts.pop_front();
+			} else if( state == 0) {
+				// this script has finished
+				// we first check if it produced output
+				// then we release the thread and remove it from the
+				// running_scripts list
+	
+				if(lua_isstring (current.thread, -1)) {
+					SCRIPT_ENGINE_TRY(process_getScriptId(current.thread, &ssr));
+					ssr.output = nse_printable
+						(lua_tostring(current.thread, -1), lua_objlen(current.thread, -1));
+					if(current.rr->type == 0) {
+						current.rr->host->scriptResults.push_back(ssr);
+					} else if(current.rr->type == 1) {
+						current.rr->port->scriptResults.push_back(ssr);
+						current.rr->host->ports.numscriptresults++;
+					}
+					lua_pop(current.thread, 2);
 				}
-				lua_pop(current.thread, 2);
+	
+				SCRIPT_ENGINE_TRY(process_finalize(l, current.registry_idx));
+				SCRIPT_ENGINE_TRY(lua_gc(l, LUA_GCCOLLECT, 0));
+			} else {
+				// this script returned because of an error
+				// print the failing reason if the verbose level is high enough	
+				SCRIPT_ENGINE_DEBUGGING(
+					const char* errmsg = lua_tostring(current.thread, -1);
+					log_write(LOG_STDOUT, "%s: %s\n", SCRIPT_ENGINE, errmsg);
+				)
+				SCRIPT_ENGINE_TRY(process_finalize(l, current.registry_idx));
 			}
-
-			SCRIPT_ENGINE_TRY(process_finalize(l, current.registry_idx));
-			SCRIPT_ENGINE_TRY(lua_gc(l, LUA_GCCOLLECT, 0));
-		} else {
-			// this script returned because of an error
-			// print the failing reason if the verbose level is high enough	
-			SCRIPT_ENGINE_DEBUGGING(
-				const char* errmsg = lua_tostring(current.thread, -1);
-				log_write(LOG_STDOUT, "%s: %s\n", SCRIPT_ENGINE, errmsg);
-			)
-			SCRIPT_ENGINE_TRY(process_finalize(l, current.registry_idx));
-		}
+		} // while
 	}
 
 	progress.endTask(NULL, NULL);
@@ -343,7 +353,8 @@ int process_mainloop(lua_State* l) {
 }
 
 // If the target still has scripts in either running_scripts
-// or waiting_scripts then it is still running
+// or waiting_scripts then it is still running.  This only
+// pertains to scripts in the current runlevel.
 
 int has_target_finished(Target *target) {
 	std::list<struct thread_record>::iterator iter;
@@ -442,9 +453,6 @@ int process_preparehost(lua_State* l, Target* target, std::list<struct thread_re
 	std::vector<run_record>::iterator iter;
 	struct run_record rr;
 
-	if (!target->timeOutClockRunning())
-		target->startTimeOutClock(NULL);
-
 	/* find the matching hostrules
 	 * */
 	lua_getglobal(l, HOSTTESTS);
@@ -499,6 +507,10 @@ int process_preparehost(lua_State* l, Target* target, std::list<struct thread_re
 		SCRIPT_ENGINE_TRY(process_pickScriptsForPort(l, target, current, torun));
 	}
 
+	while((current = plist->nextPort(current, TCPANDUDP, PORT_UNFILTERED)) != NULL) {
+		SCRIPT_ENGINE_TRY(process_pickScriptsForPort(l, target, current, torun));
+	}
+
 	// pop the hostinfo, we don't need it anymore
 	lua_pop(l, 1);
 
