@@ -5,7 +5,7 @@
  *                                                                         *
  ***********************IMPORTANT NSOCK LICENSE TERMS***********************
  *                                                                         *
- * The nsock parallel socket event library is (C) 1999-2004 Insecure.Com   *
+ * The nsock parallel socket event library is (C) 1999-2008 Insecure.Com   *
  * LLC This library is free software; you may redistribute and/or          *
  * modify it under the terms of the GNU General Public License as          *
  * published by the Free Software Foundation; Version 2.  This guarantees  *
@@ -35,7 +35,7 @@
  * Source code also allows you to port Nmap to new platforms, fix bugs,    *
  * and add new features.  You are highly encouraged to send your changes   *
  * to fyodor@insecure.org for possible incorporation into the main         *
- * distribution.  By sending these changes to Fyodor or one the            *
+ * distribution.  By sending these changes to Fyodor or one of the         *
  * insecure.org development mailing lists, it is assumed that you are      *
  * offering Fyodor and Insecure.Com LLC the unlimited, non-exclusive right *
  * to reuse, modify, and relicense the code.  Nmap will always be          *
@@ -54,7 +54,7 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: error.c,v 1.4 2004/08/29 09:12:04 fyodor Exp $ */
+/* $Id: error.c 6859 2008-02-28 18:52:17Z fyodor $ */
 
 #include "error.h"
 
@@ -64,15 +64,6 @@ fflush(stdout);vfprintf(stderr, fmt, ap);
 fprintf(stderr, "\n");va_end(ap);
 exit(1);}
 
-void myerror(char *fmt, ...) {
-va_list  ap;va_start(ap, fmt);
-fflush(stdout);
-vfprintf(stderr, fmt, ap);
-fprintf(stderr, "\n");
-va_end(ap);
-return;
-}
-
 void pfatal(char *fmt, ...) {
 va_list  ap;va_start(ap, fmt);
 fflush(stdout);
