@@ -2,7 +2,7 @@
 /***************************************************************************
  * osscan.cc -- Routines used for OS detection via TCP/IP fingerprinting.  *
  * For more information on how this works in Nmap, see my paper at         *
- * http://www.insecure.org/osdetect/                                       *
+ * http://nmap.org/osdetect/                                               *
  *                                                                         *
  ***********************IMPORTANT NMAP LICENSE TERMS************************
  *                                                                         *
@@ -39,7 +39,7 @@
  * These restrictions only apply when you actually redistribute Nmap.  For *
  * example, nothing stops you from writing and selling a proprietary       *
  * front-end to Nmap.  Just distribute it by itself, and point people to   *
- * http://insecure.org/nmap/ to download Nmap.                             *
+ * http://nmap.org to download Nmap.                                       *
  *                                                                         *
  * We don't consider these to be added restrictions on top of the GPL, but *
  * just a clarification of how we interpret "derived works" as it applies  *
@@ -78,7 +78,7 @@
  * Source code also allows you to port Nmap to new platforms, fix bugs,    *
  * and add new features.  You are highly encouraged to send your changes   *
  * to fyodor@insecure.org for possible incorporation into the main         *
- * distribution.  By sending these changes to Fyodor or one the            *
+ * distribution.  By sending these changes to Fyodor or one of the         *
  * Insecure.Org development mailing lists, it is assumed that you are      *
  * offering Fyodor and Insecure.Com LLC the unlimited, non-exclusive right *
  * to reuse, modify, and relicense the code.  Nmap will always be          *
@@ -98,7 +98,7 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: osscan.cc 6633 2007-12-22 06:32:03Z fyodor $ */
+/* $Id: osscan.cc 7099 2008-04-09 02:11:20Z fyodor $ */
 
 #include "osscan.h"
 #include "timing.h"
@@ -629,7 +629,7 @@ static bool FingerTest_lessthan(const FingerTest* a, const FingerTest* b) {
    representation. Tests that are identical between more than one fingerprint
    are included only once. If wrapit is true, the string is wrapped for
    submission. */
-char *mergeFPs(FingerPrint *FPs[], int numFPs, bool isGoodFP,
+const char *mergeFPs(FingerPrint *FPs[], int numFPs, bool isGoodFP,
 			   const struct in_addr * const addr, int distance, const u8 *mac,
 			   int openTcpPort, int closedTcpPort, int closedUdpPort, bool wrapit) {
   static char str[10240];
@@ -760,7 +760,7 @@ return str;
   }
 }
 
-char *fp2ascii(FingerPrint *FP) {
+const char *fp2ascii(FingerPrint *FP) {
 static char str[2048];
 FingerPrint *current;
 struct AVal *AV;
@@ -1139,7 +1139,7 @@ while(fgets(line, sizeof(line), fp)) {
  return DB;
 }
 
-FingerPrintDB *parse_fingerprint_reference_file(char *dbname) {
+FingerPrintDB *parse_fingerprint_reference_file(const char *dbname) {
 char filename[256];
 
 if (nmap_fetchfile(filename, sizeof(filename), dbname) != 1){
