@@ -1,12 +1,11 @@
-
 /***************************************************************************
  * osscan.h -- Routines used for OS detection via TCP/IP fingerprinting.   *
  * For more information on how this works in Nmap, see my paper at         *
- * http://www.insecure.org/nmap/nmap-fingerprinting-article.html           *
+ * http://nmap.org/osdetect/                                               *
  *                                                                         *
  ***********************IMPORTANT NMAP LICENSE TERMS************************
  *                                                                         *
- * The Nmap Security Scanner is (C) 1996-2006 Insecure.Com LLC. Nmap is    *
+ * The Nmap Security Scanner is (C) 1996-2008 Insecure.Com LLC. Nmap is    *
  * also a registered trademark of Insecure.Com LLC.  This program is free  *
  * software; you may redistribute and/or modify it under the terms of the  *
  * GNU General Public License as published by the Free Software            *
@@ -39,7 +38,7 @@
  * These restrictions only apply when you actually redistribute Nmap.  For *
  * example, nothing stops you from writing and selling a proprietary       *
  * front-end to Nmap.  Just distribute it by itself, and point people to   *
- * http://insecure.org/nmap/ to download Nmap.                             *
+ * http://nmap.org to download Nmap.                                       *
  *                                                                         *
  * We don't consider these to be added restrictions on top of the GPL, but *
  * just a clarification of how we interpret "derived works" as it applies  *
@@ -78,7 +77,7 @@
  * Source code also allows you to port Nmap to new platforms, fix bugs,    *
  * and add new features.  You are highly encouraged to send your changes   *
  * to fyodor@insecure.org for possible incorporation into the main         *
- * distribution.  By sending these changes to Fyodor or one the            *
+ * distribution.  By sending these changes to Fyodor or one of the         *
  * Insecure.Org development mailing lists, it is assumed that you are      *
  * offering Fyodor and Insecure.Com LLC the unlimited, non-exclusive right *
  * to reuse, modify, and relicense the code.  Nmap will always be          *
@@ -98,13 +97,12 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: osscan.h 4004 2006-09-25 09:08:56Z fyodor $ */
+/* $Id: osscan.h 7099 2008-04-09 02:11:20Z fyodor $ */
 
 #ifndef OSSCAN_H
 #define OSSCAN_H
 
 #include "nmap.h"
-#include "tcpip.h"
 #include "global_structures.h"
 #include "FingerPrintResults.h"
 
@@ -120,8 +118,7 @@
 /* moved to global_structures.h */
 
 /**********************  PROTOTYPES  ***********************************/
-int os_scan(Target *target);
-char *fp2ascii(FingerPrint *FP);
+const char *fp2ascii(FingerPrint *FP);
 
 /* Parses a single fingerprint from the memory region given.  If a
  non-null fingerprint is returned, the user is in charge of freeing it
@@ -134,7 +131,7 @@ FingerPrint *parse_single_fingerprint(char *fprint_orig);
    (allocated) FingerPrintDB containing the results.  They exit with
    an error message in the case of error. */
 FingerPrintDB *parse_fingerprint_file(char *fname);
-FingerPrintDB *parse_fingerprint_reference_file(char *dbname);
+FingerPrintDB *parse_fingerprint_reference_file(const char *dbname);
 
 void free_fingerprint_file(FingerPrintDB *DB);
 
@@ -158,20 +155,7 @@ void match_fingerprint(FingerPrint *FP, FingerPrintResults *FPR,
 /* Returns true if perfect match -- if num_subtests & num_subtests_succeeded are non_null it updates them.  if shortcircuit is zero, it does all the tests, otherwise it returns when the first one fails */
 
 void freeFingerPrint(FingerPrint *FP);
-char *mergeFPs(FingerPrint *FPs[], int numFPs, bool isGoodFP, const struct in_addr * const addr, int distance, const u8 *mac, int openTcpPort, int closedTcpPort, int closedUdpPort, bool wrapit);
-
-/* This function takes an array of "numSamples" IP IDs and analyzes
- them to determine their sequenceability classification.  It returns
- one of the IPID_SEQ_* classifications defined in nmap.h .  If the
- function cannot determine the sequence, IPID_SEQ_UNKNOWN is returned.
- This islocalhost argument is a boolean specifying whether these
- numbers were generated by scanning localhost.  NOTE: the "ipids" argument
- may be modified if localhost is set to true. */
-int ipid_sequence(int numSamples, u16 *ipids, int islocalhost);
+const char *mergeFPs(FingerPrint *FPs[], int numFPs, bool isGoodFP, const struct in_addr * const addr, int distance, const u8 *mac, int openTcpPort, int closedTcpPort, int closedUdpPort, bool wrapit);
 
 #endif /*OSSCAN_H*/
 
-
-
-
-
