@@ -7,7 +7,7 @@
  *                                                                         *
  ***********************IMPORTANT NMAP LICENSE TERMS************************
  *                                                                         *
- * The Nmap Security Scanner is (C) 1996-2006 Insecure.Com LLC. Nmap is    *
+ * The Nmap Security Scanner is (C) 1996-2008 Insecure.Com LLC. Nmap is    *
  * also a registered trademark of Insecure.Com LLC.  This program is free  *
  * software; you may redistribute and/or modify it under the terms of the  *
  * GNU General Public License as published by the Free Software            *
@@ -40,7 +40,7 @@
  * These restrictions only apply when you actually redistribute Nmap.  For *
  * example, nothing stops you from writing and selling a proprietary       *
  * front-end to Nmap.  Just distribute it by itself, and point people to   *
- * http://insecure.org/nmap/ to download Nmap.                             *
+ * http://nmap.org to download Nmap.                                       *
  *                                                                         *
  * We don't consider these to be added restrictions on top of the GPL, but *
  * just a clarification of how we interpret "derived works" as it applies  *
@@ -79,7 +79,7 @@
  * Source code also allows you to port Nmap to new platforms, fix bugs,    *
  * and add new features.  You are highly encouraged to send your changes   *
  * to fyodor@insecure.org for possible incorporation into the main         *
- * distribution.  By sending these changes to Fyodor or one the            *
+ * distribution.  By sending these changes to Fyodor or one of the         *
  * Insecure.Org development mailing lists, it is assumed that you are      *
  * offering Fyodor and Insecure.Com LLC the unlimited, non-exclusive right *
  * to reuse, modify, and relicense the code.  Nmap will always be          *
@@ -99,12 +99,12 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: timing.h 3869 2006-08-25 01:47:49Z fyodor $ */
+/* $Id: timing.h 7099 2008-04-09 02:11:20Z fyodor $ */
 
 #ifndef NMAP_TIMING_H
 #define NMAP_TIMING_H
 
-#include "tcpip.h"
+#include "nmap.h"
 #include "global_structures.h"
 
 /* Call this function on a newly allocated struct timeout_info to
@@ -129,10 +129,46 @@ void adjust_timeouts(struct timeval sent, struct timeout_info *to);
    time is recorded in it */
 void enforce_scan_delay(struct timeval *tv);
 
+/* This class implements current and lifetime average data rates for packets and
+   bytes. */
+class RateMeter {
+  public:
+    RateMeter();
+
+    void start(const struct timeval *now = NULL);
+    void stop(const struct timeval *now = NULL);
+    void record(u32 len, const struct timeval *now = NULL);
+    double getOverallPacketRate(const struct timeval *now = NULL) const;
+    double getCurrentPacketRate(const struct timeval *now = NULL, bool update =true);
+    double getOverallByteRate(const struct timeval *now = NULL) const;
+    double getCurrentByteRate(const struct timeval *now = NULL, bool update =true);
+
+  private:
+    /* How many seconds to look back when calculating the "current" rates. */
+    const double CURRENT_RATE_HISTORY;
+
+    /* When this meter started recording. */
+    struct timeval start_tv;
+    /* When this meter stopped recording. */
+    struct timeval stop_tv;
+    /* The last time the current sample rates were updated. */
+    struct timeval last_update_tv;
+
+    unsigned long long num_packets;
+    unsigned long long num_bytes;
+
+    double current_packet_rate;
+    double current_byte_rate;
+
+    void update(u32 packets, u32 bytes, const struct timeval *now);
+    double elapsedTime(const struct timeval *now = NULL) const;
+    static bool isSet(const struct timeval *tv);
+};
+
 class ScanProgressMeter {
  public:
   /* A COPY of stypestr is made and saved for when stats are printed */
-  ScanProgressMeter(char *stypestr);
+  ScanProgressMeter(const char *stypestr);
   ~ScanProgressMeter();
 /* Decides whether a timing report is likely to even be
    printed.  There are stringent limitations on how often they are
