@@ -155,6 +155,13 @@ this instead: '%s'" % str(id))
     def get_ports(self):
         return self._ports
 
+    # EXTRA PORTS
+    def set_extraports(self, port_list):
+        self._extraports = port_list
+    
+    def get_extraports(self):
+        return self._extraports
+
     # HOSTNAMES
     def set_hostnames(self, hostname_list):
         self._hostnames = hostname_list
@@ -261,6 +268,7 @@ zenmapCore.NmapParser.get_ipv6 instead."))
     
     def get_filtered_ports(self):
         ports = self.get_ports()
+        extraports = self.get_extraports()
         filtered = 0
         
         for i in ports:
@@ -269,10 +277,15 @@ zenmapCore.NmapParser.get_ipv6 instead."))
                 if re.findall('filtered', p['port_state']):
                     filtered+=1
  
+        for extra in extraports:
+            if extra["state"] == "filtered":
+                filtered += int(extra["count"])
+
         return filtered
     
     def get_closed_ports(self):
         ports = self.get_ports()
+        extraports = self.get_extraports()
         closed = 0
         
         for i in ports:
@@ -281,10 +294,15 @@ zenmapCore.NmapParser.get_ipv6 instead."))
                 if re.findall('closed', p['port_state']):
                     closed+=1
         
+        for extra in extraports:
+            if extra["state"] == "closed":
+                closed += int(extra["count"])
+
         return closed
     
     def get_scanned_ports(self):
         ports = self.get_ports()
+        extraports = self.get_extraports()
         scanned = 0
         
         for i in ports:
@@ -292,6 +310,9 @@ zenmapCore.NmapParser.get_ipv6 instead."))
             for p in port:
                 scanned+=1
         
+        for extra in extraports:
+            scanned += int(extra["count"])
+
         return scanned
 
     def get_services(self):
@@ -314,6 +335,7 @@ zenmapCore.NmapParser.get_ipv6 instead."))
     osmatch = property(get_osmatch, set_osmatch)
     ports = property(get_ports, set_ports)
     ports_used = property(get_ports_used, set_ports_used)
+    extraports = property(get_extraports, set_extraports)
     uptime = property(get_uptime, set_uptime)
     hostnames = property(get_hostnames, set_hostnames)
     tcptssequence = property(get_tcptssequence, set_tcptssequence)
@@ -331,6 +353,7 @@ zenmapCore.NmapParser.get_ipv6 instead."))
     _osmatch = []
     _ports = []
     _ports_used = []
+    _extraports = []
     _uptime = {}
     _hostnames = []
     _tcptssequence = {}
@@ -521,12 +544,6 @@ in epoch format!")
         for h in self.nmap.get('hosts', []):
             ports += h.get_filtered_ports()
         
-        for extra in self.list_extraports:
-            if extra["state"] == "filtered":
-                ports += int(extra["count"])
-
-        log.debug(">>> EXTRAPORTS: %s" % str(self.list_extraports))
-
         return ports
 
     def get_closed_ports(self):
@@ -535,10 +552,6 @@ in epoch format!")
         for h in self.nmap['hosts']:
             ports += h.get_closed_ports()
 
-        for extra in self.list_extraports:
-            if extra["state"] == "closed":
-                ports += int(extra["count"])
-
         return ports
 
     def get_formated_date(self):
@@ -889,7 +902,6 @@ class NmapParserSAX(ParserBasics, ContentHandler):
 
     def _parse_host_tcpsequence(self, attrs):
         self.host_info.set_tcpsequence(self._parsing(attrs, ['index',
-                                                             'class',
                                                              'difficulty',
                                                              'values']))
     
@@ -979,6 +991,7 @@ class NmapParserSAX(ParserBasics, ContentHandler):
             self.in_ports = False
             self.list_ports.append({"extraports":self.list_extraports,
                                     "port":self.list_port})
+            self.host_info.set_extraports(self.list_extraports)
         elif self.in_host and self.in_ports and name == "port":
             self.in_port = False
             self.list_port.append(self.dic_port)
@@ -1192,7 +1205,6 @@ class NmapParserSAX(ParserBasics, ContentHandler):
             if type(host.tcpsequence) == type({}):
                 self.write_parser.startElement("tcpsequence",
                     Attributes({"index":host.tcpsequence.get("index", ""),
-                            "class":host.tcpsequence.get("class", ""),
                             "difficulty":host.tcpsequence.get("difficulty", ""),
                             "values":host.tcpsequence.get("values", "")}))
                 self.write_parser.endElement("tcpsequence")
