@@ -104,6 +104,7 @@ profile_editor_content = '''<?xml version="1.0"?>
   <groups>
     <group name="Scan"/>
     <group name="Ping"/>
+    <group name="Scripting"/>
     <group name="Target"/>
     <group name="Source"/>
     <group name="Other"/>
@@ -120,8 +121,9 @@ profile_editor_content = '''<?xml version="1.0"?>
       <option name="Window Scan"/>
       <option name="Xmas Tree"/>
     </option_list>    
-    <option_list label="Special scans: ">
+    <option_list label="Non-TCP scans: ">
       <option name="None"/>
+      <option name="UDP Scan"/>
       <option name="IP protocol Scan"/>
       <option name="List Scan"/>
       <option name="Ping scanning"/>
@@ -152,7 +154,15 @@ profile_editor_content = '''<?xml version="1.0"?>
     <option_check label="ACK ping" option="TCP ACK" arg_type="str"/>
     <option_check label="SYN ping" option="TCP SYN" arg_type="str"/>
     <option_check label="UDP probes" option="UDP Probe" arg_type="str"/>
+    <option_check label="IPProto probes" option="IPProto Probe" arg_type="str"/>
   </Ping>
+  <Scripting label="Scripting options (NSE)">
+    <option_check label="Script scan" option="Script scan"/>
+    <option_check label="Scripts to run" option="Script selection" arg_type="str"/>
+    <option_check label="Script arguments" option="Script arguments" arg_type="str"/>
+    <option_check label="Trace script execution" option="Script trace"/>
+    <!-- <option_check label="Trace script execution" option="Script trace"/> -->
+  </Scripting>
   <Target label="Target options">
     <option_check label="Excluded hosts/networks" option="Excluded hosts/networks" arg_type="str"/>
     <option_check label="Excluded hosts/networks from file" option="Excluded hosts/networks from file" arg_type="path"/>
@@ -168,7 +178,7 @@ profile_editor_content = '''<?xml version="1.0"?>
     <option_check label="Set network interface" option="Set network interface" arg_type="str"/>
   </Source>
   <Other label="Other options">
-    <option_check label="Extra options definied by user" option="Extra" arg_type="str"/>
+    <option_check label="Extra options defined by user" option="Extra" arg_type="str"/>
     <option_check label="Set IPv4 time to live (ttl)" option="Set IPv4 ttl" arg_type="str"/>
     <option_check label="Fragment IP packets" option="Fragment IP Packets"/>
     <option_check label="Verbosity level" option="Verbose" arg_type="level"/>
@@ -318,6 +328,36 @@ options_content = '''<?xml version="1.0"?>
           arguments=""
           need_root="0"/>
           
+  <option name="Script scan"
+          option="-sC"
+          hint="Try to detect version of services on scanned hosts"
+          arguments=""
+          need_root="0"/>
+          
+  <option name="Script selection"
+          option="--script=%s"
+          hint="Run selected scripts"
+          arguments="A comma-separated list of scripts categories, directories, or files"
+          need_root="0"/>
+          
+  <option name="Script arguments"
+          option="--script-args=%s"
+          hint="Arguments to give to scripts, in the form n1=v1,n2=v2,..."
+          arguments=""
+          need_root="0"/>
+          
+  <option name="Script trace"
+          option="--script-trace"
+          hint="Show data sent and received by scripts"
+          arguments=""
+          need_root="0"/>
+          
+  <option name="Update script database"
+          option="--script-updatedb"
+          hint="Update the script database"
+          arguments=""
+          need_root="0"/>
+          
   <option name="Operating system detection"
           option="-O"
           hint="Try to detect running OS on scanned hosts"
@@ -354,6 +394,12 @@ options_content = '''<?xml version="1.0"?>
           arguments="List of targeted ports"
           need_root="0"/>
           
+  <option name="IPProto Probe"
+          option="-PO%s"
+          hint="IP protocol probes to ping a host or network"
+          arguments="List of targeted ports"
+          need_root="1"/>
+          
   <option name="ICMP ping"
           option="-PE"
           hint="ICMP ping a host or network"
@@ -553,13 +599,13 @@ options_content = '''<?xml version="1.0"?>
           need_root="0"/>
           
   <option name="Max time between probes"
-          option="--scan_delay %s"
+          option="--max_scan_delay %s"
           hint="Maximum time between scan probes"
           arguments=""
           need_root="0"/>
           
   <option name="Min time between probes"
-          option="--max_scan_delay %s"
+          option="--scan_delay %s"
           hint="Minimum time between scan probes"
           arguments=""
           need_root="0"/>
@@ -615,8 +661,9 @@ wizard_content = '''<?xml version="1.0"?>
       <option name="Window Scan"/>
       <option name="Xmas Tree"/>
     </option_list>
-    <option_list label="Special scans: ">
+    <option_list label="Non-TCP scans: ">
       <option name="None"/>
+      <option name="UDP Scan"/>
       <option name="IP protocol Scan"/>
       <option name="List Scan"/>
       <option name="Ping scanning"/>
@@ -642,6 +689,7 @@ wizard_content = '''<?xml version="1.0"?>
     <option_check label="ACK ping" option="TCP ACK" arg_type="str"/>
     <option_check label="SYN ping" option="TCP SYN" arg_type="str"/>
     <option_check label="UDP probes" option="UDP Probe" arg_type="str"/>
+    <option_check label="IPProto probes" option="IPProto Probe" arg_type="str"/>
   </Ping>
   <Target label="Target options">
     <option_check label="Excluded hosts/networks" option="Excluded hosts/networks" arg_type="str"/>
@@ -654,7 +702,7 @@ wizard_content = '''<?xml version="1.0"?>
     <option_check label="Set source port" option="Set source port" arg_type="str"/>
   </Source>
   <Other label="Other options">
-    <option_check label="Extra options definied by user" option="Extra" arg_type="str"/>
+    <option_check label="Extra options defined by user" option="Extra" arg_type="str"/>
     <option_check label="Set IPv4 time to live (ttl)" option="Set IPv4 ttl" arg_type="str"/>
     <option_check label="Fragment IP packets" option="Fragment IP Packets"/>
     <option_check label="Verbosity level" option="Verbose" arg_type="level"/>
